=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2009-01-18 06:11:18 +0000
+++ bzrlib/builtins.py	2009-01-29 07:53:46 +0000
@@ -1875,7 +1875,7 @@
             log_format=None,
             message=None,
             limit=None):
-        from bzrlib.log import show_log
+        from bzrlib.log import show_log, _get_fileid_to_log
         direction = (forward and 'forward') or 'reverse'
 
         if change is not None:
@@ -1933,44 +1933,6 @@
         finally:
             b.unlock()
 
-def _get_fileid_to_log(revision, tree, b, fp):
-    if revision is None:
-        if tree is None:
-            tree = b.basis_tree()
-        file_id = tree.path2id(fp)
-        if file_id is None:
-            # go back to when time began
-            rev1 = b.get_rev_id(1)
-            tree = b.repository.revision_tree(rev1)
-            file_id = tree.path2id(fp)
-
-    elif len(revision) == 1:
-        # One revision given - file must exist in it
-        tree = revision[0].as_tree(b)
-        file_id = tree.path2id(fp)
-
-    elif len(revision) == 2:
-        # Revision range given. Get the file-id from the end tree.
-        # If that fails, try the start tree.
-        rev_id = revision[1].as_revision_id(b)
-        if rev_id is None:
-            tree = b.basis_tree()
-        else:
-            tree = revision[1].as_tree(b)
-        file_id = tree.path2id(fp)
-        if file_id is None:
-            rev_id = revision[0].as_revision_id(b)
-            if rev_id is None:
-                rev1 = b.get_rev_id(1)
-                tree = b.repository.revision_tree(rev1)
-            else:
-                tree = revision[0].as_tree(b)
-            file_id = tree.path2id(fp)
-    else:
-        raise errors.BzrCommandError(
-            'bzr log --revision takes one or two values.')
-    return file_id
-
 
 def _get_revision_range(revisionspec_list, branch, command_name):
     """Take the input of a revision option and turn it into a revision range.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2009-01-15 14:05:13 +0000
+++ bzrlib/log.py	2009-01-29 07:53:46 +0000
@@ -1110,6 +1110,52 @@
         lf.log_revision(lr)
 
 
+def _get_fileid_to_log(revision, tree, b, fp):
+    """Find the file-id to log for a file path in a revision range.
+
+    :param revision: the revision range as parsed on the command line
+    :param tree: the working tree, if any
+    :param b: the branch
+    :param fp: file path
+    """
+    if revision is None:
+        if tree is None:
+            tree = b.basis_tree()
+        file_id = tree.path2id(fp)
+        if file_id is None:
+            # go back to when time began
+            rev1 = b.get_rev_id(1)
+            tree = b.repository.revision_tree(rev1)
+            file_id = tree.path2id(fp)
+
+    elif len(revision) == 1:
+        # One revision given - file must exist in it
+        tree = revision[0].as_tree(b)
+        file_id = tree.path2id(fp)
+
+    elif len(revision) == 2:
+        # Revision range given. Get the file-id from the end tree.
+        # If that fails, try the start tree.
+        rev_id = revision[1].as_revision_id(b)
+        if rev_id is None:
+            tree = b.basis_tree()
+        else:
+            tree = revision[1].as_tree(b)
+        file_id = tree.path2id(fp)
+        if file_id is None:
+            rev_id = revision[0].as_revision_id(b)
+            if rev_id is None:
+                rev1 = b.get_rev_id(1)
+                tree = b.repository.revision_tree(rev1)
+            else:
+                tree = revision[0].as_tree(b)
+            file_id = tree.path2id(fp)
+    else:
+        raise errors.BzrCommandError(
+            'bzr log --revision takes one or two values.')
+    return file_id
+
+
 properties_handler_registry = registry.Registry()
 properties_handler_registry.register_lazy("foreign",
                                           "bzrlib.foreign",

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2009-01-18 06:11:18 +0000
+++ bzrlib/tests/blackbox/test_log.py	2009-01-29 07:53:46 +0000
@@ -585,18 +585,18 @@
         self.assertNotContainsRe(log, 'revno: 3.1.1\n')
         self.assertNotContainsRe(log, 'revno: 4\n')
 
-    def test_log_file_historical(self):
-        """File matched against revision range, not current tree."""
-        self.prepare_tree(complex=True)
-
+    def test_log_file_historical_missing(self):
         # Check logging a deleted file gives an error if the
         # file isn't found at the end or start of the revision range
+        self.prepare_tree(complex=True)
         err_msg = "Path unknown at end or start of revision range: file2"
         err = self.run_bzr('log file2', retcode=3)[1]
         self.assertContainsRe(err, err_msg)
 
+    def test_log_file_historical_end(self):
         # Check logging a deleted file is ok if the file existed
         # at the end the revision range
+        self.prepare_tree(complex=True)
         log, err = self.run_bzr('log -r..4 file2')
         self.assertEquals('', err)
         self.assertNotContainsRe(log, 'revno: 1\n')
@@ -605,8 +605,10 @@
         self.assertContainsRe(log, 'revno: 3.1.1\n')
         self.assertContainsRe(log, 'revno: 4\n')
 
+    def test_log_file_historical_start(self):
         # Check logging a deleted file is ok if the file existed
         # at the start of the revision range
+        self.prepare_tree(complex=True)
         log, err = self.run_bzr('log file1')
         self.assertEquals('', err)
         self.assertContainsRe(log, 'revno: 1\n')

